@@ -15,8 +15,15 @@ from docutils import nodes
 
 from sphinx import addnodes
 
+if False:
+    # For type annotation
+    from typing import Any, Dict, List, Tuple  # NOQA
+    from sphinx.domains import Domain  # NOQA
+    from sphinx.environment import BuildEnvironment  # NOQA
+
 
 def _is_single_paragraph(node):
+    # type: (nodes.Node) -> bool
     """True if the node only contains one paragraph (and system messages)."""
     if len(node) == 0:
         return False
@@ -47,6 +54,7 @@ class Field(object):
 
     def __init__(self, name, names=(), label=None, has_arg=True, rolename=None,
                  bodyrolename=None):
+        # type: (unicode, Tuple[unicode, ...], unicode, bool, unicode, unicode) -> None
         self.name = name
         self.names = names
         self.label = label
@@ -54,8 +62,15 @@ class Field(object):
         self.rolename = rolename
         self.bodyrolename = bodyrolename
 
-    def make_xref(self, rolename, domain, target,
-                  innernode=addnodes.literal_emphasis, contnode=None, env=None):
+    def make_xref(self,
+                  rolename,       # type: unicode
+                  domain,         # type: unicode
+                  target,         # type: unicode
+                  innernode=addnodes.literal_emphasis,  # type: nodes.Node
+                  contnode=None,  # type: nodes.Node
+                  env=None,       # type: BuildEnvironment
+                  ):
+        # type: (...) -> nodes.Node
         if not rolename:
             return contnode or innernode(target, target)
         refnode = addnodes.pending_xref('', refdomain=domain, refexplicit=False,
@@ -65,14 +80,28 @@ class Field(object):
             env.domains[domain].process_field_xref(refnode)
         return refnode
 
-    def make_xrefs(self, rolename, domain, target,
-                   innernode=addnodes.literal_emphasis, contnode=None, env=None):
+    def make_xrefs(self,
+                   rolename,       # type: unicode
+                   domain,         # type: unicode
+                   target,         # type: unicode
+                   innernode=addnodes.literal_emphasis,  # type: nodes.Node
+                   contnode=None,  # type: nodes.Node
+                   env=None,       # type: BuildEnvironment
+                   ):
+        # type: (...) -> List[nodes.Node]
         return [self.make_xref(rolename, domain, target, innernode, contnode, env)]
 
     def make_entry(self, fieldarg, content):
+        # type: (List, unicode) -> Tuple[List, unicode]
         return (fieldarg, content)
 
-    def make_field(self, types, domain, item, env=None):
+    def make_field(self,
+                   types,     # type: Dict[unicode, List[nodes.Node]]
+                   domain,    # type: unicode
+                   item,      # type: Tuple
+                   env=None,  # type: BuildEnvironment
+                   ):
+        # type: (...) -> nodes.field
         fieldarg, content = item
         fieldname = nodes.field_name('', self.label)
         if fieldarg:
@@ -108,10 +137,17 @@ class GroupedField(Field):
 
     def __init__(self, name, names=(), label=None, rolename=None,
                  can_collapse=False):
+        # type: (unicode, Tuple[unicode, ...], unicode, unicode, bool) -> None
         Field.__init__(self, name, names, label, True, rolename)
         self.can_collapse = can_collapse
 
-    def make_field(self, types, domain, items, env=None):
+    def make_field(self,
+                   types,     # type: Dict[unicode, List[nodes.Node]]
+                   domain,    # type: unicode
+                   items,     # type: Tuple
+                   env=None,  # type: BuildEnvironment
+                   ):
+        # type: (...) -> nodes.field
         fieldname = nodes.field_name('', self.label)
         listnode = self.list_type()
         for fieldarg, content in items:
@@ -153,12 +189,20 @@ class TypedField(GroupedField):
 
     def __init__(self, name, names=(), typenames=(), label=None,
                  rolename=None, typerolename=None, can_collapse=False):
+        # type: (unicode, Tuple[unicode, ...], Tuple[unicode, ...], unicode, unicode, unicode, bool) -> None  # NOQA
         GroupedField.__init__(self, name, names, label, rolename, can_collapse)
         self.typenames = typenames
         self.typerolename = typerolename
 
-    def make_field(self, types, domain, items, env=None):
+    def make_field(self,
+                   types,     # type: Dict[unicode, List[nodes.Node]]
+                   domain,    # type: unicode
+                   items,     # type: Tuple
+                   env=None,  # type: BuildEnvironment
+                   ):
+        # type: (...) -> nodes.field
         def handle_item(fieldarg, content):
+            # type: (unicode, unicode) -> nodes.paragraph
             par = nodes.paragraph()
             par.extend(self.make_xrefs(self.rolename, domain, fieldarg,
                                        addnodes.literal_strong, env=env))
@@ -198,6 +242,7 @@ class DocFieldTransformer(object):
     """
 
     def __init__(self, directive):
+        # type: (Any) -> None
         self.directive = directive
         if '_doc_field_type_map' not in directive.__class__.__dict__:
             directive.__class__._doc_field_type_map = \
@@ -205,6 +250,7 @@ class DocFieldTransformer(object):
         self.typemap = directive._doc_field_type_map
 
     def preprocess_fieldtypes(self, types):
+        # type: (List) -> Dict[unicode, Tuple[Any, bool]]
         typemap = {}
         for fieldtype in types:
             for name in fieldtype.names:
@@ -215,6 +261,7 @@ class DocFieldTransformer(object):
         return typemap
 
     def transform_all(self, node):
+        # type: (nodes.Node) -> None
         """Transform all field list children of a node."""
         # don't traverse, only handle field lists that are immediate children
         for child in node:
@@ -222,12 +269,13 @@ class DocFieldTransformer(object):
                 self.transform(child)
 
     def transform(self, node):
+        # type: (nodes.Node) -> None
         """Transform a single field list *node*."""
         typemap = self.typemap
 
         entries = []
-        groupindices = {}
-        types = {}
+        groupindices = {}  # type: Dict[unicode, int]
+        types = {}  # type: Dict[unicode, Dict]
 
         # step 1: traverse all fields and collect field types and content
         for field in node:
@@ -282,6 +330,7 @@ class DocFieldTransformer(object):
 
             translatable_content = nodes.inline(fieldbody.rawsource,
                                                 translatable=True)
+            translatable_content.document = fieldbody.parent.document
             translatable_content.source = fieldbody.parent.source
             translatable_content.line = fieldbody.parent.line
             translatable_content += content
