@@ -8,14 +8,12 @@
     :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
-import codecs
-
 from docutils import nodes
 
 from sphinx.application import ExtensionError
 from sphinx.domains import Domain
 
-from util import strip_escseq
+from sphinx.testing.util import strip_escseq
 import pytest
 
 
@@ -49,40 +47,6 @@ def test_emit_with_nonascii_name_node(app, status, warning):
     app.emit('my_event', node)
 
 
-def test_output(app, status, warning):
-    # info with newline
-    status.truncate(0)  # __init__ writes to status
-    status.seek(0)
-    app.info("Nothing here...")
-    assert status.getvalue() == "Nothing here...\n"
-    # info without newline
-    status.truncate(0)
-    status.seek(0)
-    app.info("Nothing here...", True)
-    assert status.getvalue() == "Nothing here..."
-
-    # warning
-    old_count = app._warncount
-    app.warn("Bad news!")
-    assert strip_escseq(warning.getvalue()) == "WARNING: Bad news!\n"
-    assert app._warncount == old_count + 1
-
-
-def test_output_with_unencodable_char(app, status, warning):
-
-    class StreamWriter(codecs.StreamWriter):
-        def write(self, object):
-            self.stream.write(object.encode('cp1252').decode('cp1252'))
-
-    app._status = StreamWriter(status)
-
-    # info with UnicodeEncodeError
-    status.truncate(0)
-    status.seek(0)
-    app.info(u"unicode \u206d...")
-    assert status.getvalue() == "unicode ?...\n"
-
-
 def test_extensions(app, status, warning):
     app.setup_extension('shutil')
     assert strip_escseq(warning.getvalue()).startswith("WARNING: extension 'shutil'")
@@ -119,13 +83,6 @@ def test_domain_override(app, status, warning):
 @pytest.mark.sphinx(testroot='add_source_parser')
 def test_add_source_parser(app, status, warning):
     assert set(app.config.source_suffix) == set(['.rst', '.md', '.test'])
-    assert set(app.config.source_parsers.keys()) == set(['.md', '.test'])
-    assert app.config.source_parsers['.md'].__name__ == 'DummyMarkdownParser'
-    assert app.config.source_parsers['.test'].__name__ == 'TestSourceParser'
-
-
-@pytest.mark.sphinx(testroot='add_source_parser-conflicts-with-users-setting')
-def test_add_source_parser_conflicts_with_users_setting(app, status, warning):
-    assert set(app.config.source_suffix) == set(['.rst', '.test'])
-    assert set(app.config.source_parsers.keys()) == set(['.test'])
-    assert app.config.source_parsers['.test'].__name__ == 'DummyTestParser'
+    assert set(app.registry.get_source_parsers().keys()) == set(['*', '.md', '.test'])
+    assert app.registry.get_source_parsers()['.md'].__name__ == 'DummyMarkdownParser'
+    assert app.registry.get_source_parsers()['.test'].__name__ == 'TestSourceParser'
