@@ -16,7 +16,8 @@ from itertools import cycle, chain
 from six import PY3
 
 from sphinx import __display_version__
-from util import remove_unicode_literals, strip_escseq
+from sphinx.util.inventory import InventoryFile
+from sphinx.testing.util import remove_unicode_literals, strip_escseq
 import xml.etree.cElementTree as ElementTree
 from html5lib import getTreeBuilder, HTMLParser
 import pytest
@@ -31,7 +32,6 @@ WARNING: Explicit markup ends without a blank line; unexpected unindent.
 %(root)s/index.rst:\\d+: WARNING: Encoding 'utf-8-sig' used for reading included \
 file u'%(root)s/wrongenc.inc' seems to be wrong, try giving an :encoding: option
 %(root)s/index.rst:\\d+: WARNING: image file not readable: foo.png
-%(root)s/index.rst:\\d+: WARNING: nonlocal image URI found: http://www.python.org/logo.png
 %(root)s/index.rst:\\d+: WARNING: download file not readable: %(root)s/nonexisting.png
 %(root)s/index.rst:\\d+: WARNING: invalid single index entry u''
 %(root)s/undecodable.rst:\\d+: WARNING: undecodable source characters, replacing \
@@ -39,10 +39,10 @@ with "\\?": b?'here: >>>(\\\\|/)xbb<<<((\\\\|/)r)?'
 """
 
 HTML_WARNINGS = ENV_WARNINGS + """\
-%(root)s/index.rst:\\d+: WARNING: no matching candidate for image URI u'foo.\\*'
-%(root)s/index.rst:\\d+: WARNING: Could not lex literal_block as "c". Highlighting skipped.
 %(root)s/index.rst:\\d+: WARNING: unknown option: &option
 %(root)s/index.rst:\\d+: WARNING: citation not found: missing
+%(root)s/index.rst:\\d+: WARNING: no matching candidate for image URI u'foo.\\*'
+%(root)s/index.rst:\\d+: WARNING: Could not lex literal_block as "c". Highlighting skipped.
 """
 
 if PY3:
@@ -109,9 +109,9 @@ def check_xpath(etree, fname, path, check, be_found=True):
                 # Since pygments-2.1.1, empty <span> tag is inserted at top of
                 # highlighting block
                 if len(node) == 1 and node[0].tag == 'span' and node[0].text is None:
-                    return node[0].tail
-                else:
-                    return ''
+                    if node[0].tail is not None:
+                        return node[0].tail
+                return ''
 
         rex = re.compile(check)
         if be_found:
@@ -147,7 +147,7 @@ def check_extra_entries(outdir):
 @pytest.mark.sphinx('html', testroot='warnings')
 def test_html_warnings(app, warning):
     app.build()
-    html_warnings = strip_escseq(warning.getvalue().replace(os.sep, '/'))
+    html_warnings = strip_escseq(re.sub(re.escape(os.sep) + '{1,2}', '/', warning.getvalue()))
     html_warnings_exp = HTML_WARNINGS % {
         'root': re.escape(app.srcdir.replace(os.sep, '/'))}
     assert re.match(html_warnings_exp + '$', html_warnings), \
@@ -297,6 +297,13 @@ def test_static_output(app):
         # tests for ``any`` role
         (".//a[@href='#with']/span", 'headings'),
         (".//a[@href='objects.html#func_without_body']/code/span", 'objects'),
+        # tests for smartypants
+        (".//li", u'Smart “quotes” in English ‘text’.'),
+        (".//li", u'Smart — long and – short dashes.'),
+        (".//li", u'Ellipsis…'),
+        (".//li//code//span[@class='pre']", 'foo--"bar"...'),
+        (".//p", u'Этот «абзац» должен использовать „русские“ кавычки.'),
+        (".//p", u'Il dit : « C’est “super” ! »'),
     ],
     'objects.html': [
         (".//dt[@id='mod.Cls.meth1']", ''),
@@ -346,7 +353,7 @@ def test_static_output(app):
         (".//a[@class='reference internal'][@href='#cmdoption-perl-arg-p']/code/span",
          'perl'),
         (".//a[@class='reference internal'][@href='#cmdoption-perl-arg-p']/code/span",
-         '\+p'),
+         '\\+p'),
         (".//a[@class='reference internal'][@href='#cmdoption-perl-objc']/code/span",
          '--ObjC\\+\\+'),
         (".//a[@class='reference internal'][@href='#cmdoption-perl-plugin-option']/code/span",
@@ -415,18 +422,21 @@ def test_static_output(app):
         (".//li/a", "double"),
     ],
     'footnote.html': [
-        (".//a[@class='footnote-reference'][@href='#id7'][@id='id1']", r"\[1\]"),
-        (".//a[@class='footnote-reference'][@href='#id8'][@id='id2']", r"\[2\]"),
+        (".//a[@class='footnote-reference'][@href='#id9'][@id='id1']", r"\[1\]"),
+        (".//a[@class='footnote-reference'][@href='#id10'][@id='id2']", r"\[2\]"),
         (".//a[@class='footnote-reference'][@href='#foo'][@id='id3']", r"\[3\]"),
         (".//a[@class='reference internal'][@href='#bar'][@id='id4']", r"\[bar\]"),
-        (".//a[@class='footnote-reference'][@href='#id9'][@id='id5']", r"\[4\]"),
-        (".//a[@class='footnote-reference'][@href='#id10'][@id='id6']", r"\[5\]"),
+        (".//a[@class='reference internal'][@href='#baz-qux'][@id='id5']", r"\[baz_qux\]"),
+        (".//a[@class='footnote-reference'][@href='#id11'][@id='id6']", r"\[4\]"),
+        (".//a[@class='footnote-reference'][@href='#id12'][@id='id7']", r"\[5\]"),
         (".//a[@class='fn-backref'][@href='#id1']", r"\[1\]"),
         (".//a[@class='fn-backref'][@href='#id2']", r"\[2\]"),
         (".//a[@class='fn-backref'][@href='#id3']", r"\[3\]"),
         (".//a[@class='fn-backref'][@href='#id4']", r"\[bar\]"),
-        (".//a[@class='fn-backref'][@href='#id5']", r"\[4\]"),
-        (".//a[@class='fn-backref'][@href='#id6']", r"\[5\]"),
+        (".//a[@class='fn-backref'][@href='#id5']", r"\[baz_qux\]"),
+        (".//a[@class='fn-backref'][@href='#id6']", r"\[4\]"),
+        (".//a[@class='fn-backref'][@href='#id7']", r"\[5\]"),
+        (".//a[@class='fn-backref'][@href='#id8']", r"\[6\]"),
     ],
     'otherext.html': [
         (".//h1", "Generated section"),
@@ -441,6 +451,12 @@ def test_html_output(app, cached_etree_parse, fname, expect):
     check_xpath(cached_etree_parse(app.outdir / fname), fname, *expect)
 
 
+@pytest.mark.sphinx('html', testroot='build-html-translator')
+def test_html_translator(app):
+    app.build()
+    assert app.builder.docwriter.visitor.depart_with_node == 10
+
+
 @pytest.mark.parametrize("fname,expect", flat_dict({
     'index.html': [
         (".//li[@class='toctree-l3']/a", '1.1.1. Foo A1', True),
@@ -581,7 +597,7 @@ def test_numfig_without_numbered_toctree_warn(app, warning):
     app.build()
     # remove :numbered: option
     index = (app.srcdir / 'index.rst').text()
-    index = re.sub(':numbered:.*', '', index, re.MULTILINE)
+    index = re.sub(':numbered:.*', '', index)
     (app.srcdir / 'index.rst').write_text(index, encoding='utf-8')
     app.builder.build_all()
 
@@ -679,7 +695,7 @@ def test_numfig_without_numbered_toctree_warn(app, warning):
 def test_numfig_without_numbered_toctree(app, cached_etree_parse, fname, expect):
     # remove :numbered: option
     index = (app.srcdir / 'index.rst').text()
-    index = re.sub(':numbered:.*', '', index, re.MULTILINE)
+    index = re.sub(':numbered:.*', '', index)
     (app.srcdir / 'index.rst').write_text(index, encoding='utf-8')
 
     if not app.outdir.listdir():
@@ -1148,3 +1164,84 @@ def test_html_entity(app):
     content = (app.outdir / 'index.html').text()
     for entity in re.findall(r'&([a-z]+);', content, re.M):
         assert entity not in valid_entities
+
+
+@pytest.mark.sphinx('html', testroot='basic')
+@pytest.mark.xfail(os.name != 'posix', reason="Not working on windows")
+def test_html_inventory(app):
+    app.builder.build_all()
+    with open(app.outdir / 'objects.inv', 'rb') as f:
+        invdata = InventoryFile.load(f, 'http://example.com', os.path.join)
+    assert set(invdata.keys()) == {'std:label', 'std:doc'}
+    assert set(invdata['std:label'].keys()) == {'modindex', 'genindex', 'search'}
+    assert invdata['std:label']['modindex'] == ('Python',
+                                                '',
+                                                'http://example.com/py-modindex.html',
+                                                'Module Index')
+    assert invdata['std:label']['genindex'] == ('Python',
+                                                '',
+                                                'http://example.com/genindex.html',
+                                                'Index')
+    assert invdata['std:label']['search'] == ('Python',
+                                              '',
+                                              'http://example.com/search.html',
+                                              'Search Page')
+    assert set(invdata['std:doc'].keys()) == {'index'}
+    assert invdata['std:doc']['index'] == ('Python',
+                                           '',
+                                           'http://example.com/index.html',
+                                           'The basic Sphinx documentation for testing')
+
+
+@pytest.mark.sphinx('html', testroot='directives-raw')
+def test_html_raw_directive(app, status, warning):
+    app.builder.build_all()
+    result = (app.outdir / 'index.html').text(encoding='utf8')
+
+    # standard case
+    assert 'standalone raw directive (HTML)' in result
+    assert 'standalone raw directive (LaTeX)' not in result
+
+    # with substitution
+    assert '<p>HTML: abc def ghi</p>' in result
+    assert '<p>LaTeX: abc  ghi</p>' in result
+
+
+@pytest.mark.parametrize("fname,expect", flat_dict({
+    'index.html': [
+        (".//link[@href='_static/persistent.css']"
+         "[@rel='stylesheet']", '', True),
+        (".//link[@href='_static/default.css']"
+         "[@rel='stylesheet']"
+         "[@title='Default']", '', True),
+        (".//link[@href='_static/alternate1.css']"
+         "[@rel='alternate stylesheet']"
+         "[@title='Alternate']", '', True),
+        (".//link[@href='_static/alternate2.css']"
+         "[@rel='alternate stylesheet']", '', True),
+        (".//link[@href='_static/more_persistent.css']"
+         "[@rel='stylesheet']", '', True),
+        (".//link[@href='_static/more_default.css']"
+         "[@rel='stylesheet']"
+         "[@title='Default']", '', True),
+        (".//link[@href='_static/more_alternate1.css']"
+         "[@rel='alternate stylesheet']"
+         "[@title='Alternate']", '', True),
+        (".//link[@href='_static/more_alternate2.css']"
+         "[@rel='alternate stylesheet']", '', True),
+    ],
+}))
+@pytest.mark.sphinx('html', testroot='stylesheets')
+def test_alternate_stylesheets(app, cached_etree_parse, fname, expect):
+    app.build()
+    check_xpath(cached_etree_parse(app.outdir / fname), fname, *expect)
+
+
+@pytest.mark.sphinx('html', testroot='images')
+def test_html_remote_images(app, status, warning):
+    app.builder.build_all()
+
+    result = (app.outdir / 'index.html').text(encoding='utf8')
+    assert ('<img alt="https://www.python.org/static/img/python-logo.png" '
+            'src="https://www.python.org/static/img/python-logo.png" />' in result)
+    assert not (app.outdir / 'python-logo.png').exists()
