@@ -19,7 +19,7 @@ import pytest
 
 from sphinx.writers.texinfo import TexinfoTranslator
 
-from util import SkipTest, remove_unicode_literals, strip_escseq
+from sphinx.testing.util import SkipTest, remove_unicode_literals, strip_escseq
 from test_build_html import ENV_WARNINGS
 
 
@@ -37,7 +37,7 @@ if PY3:
 @pytest.mark.sphinx('texinfo', testroot='warnings', freshenv=True)
 def test_texinfo_warnings(app, status, warning):
     app.builder.build_all()
-    warnings = strip_escseq(warning.getvalue().replace(os.sep, '/'))
+    warnings = strip_escseq(re.sub(re.escape(os.sep) + '{1,2}', '/', warning.getvalue()))
     warnings_exp = TEXINFO_WARNINGS % {
         'root': re.escape(app.srcdir.replace(os.sep, '/'))}
     assert re.match(warnings_exp + '$', warnings), \
